==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/DataLegendSeriesContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataLegendSeriesContextDescription } from "./DataLegendSeriesContextDescription";
/**
 * @hidden
 */
var DataLegendSeriesContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(DataLegendSeriesContextDescriptionMetadata, _super);
    function DataLegendSeriesContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataLegendSeriesContextDescriptionMetadata.b = function (a) {
        if (DataLegendSeriesContextDescriptionMetadata.a == null) {
            DataLegendSeriesContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataLegendSeriesContextDescriptionMetadata.c(DataLegendSeriesContextDescriptionMetadata.a);
        }
        if (a.g(DataLegendSeriesContextDescriptionMetadata.a)) {
            return;
        }
        a.s(DataLegendSeriesContextDescriptionMetadata.a);
    };
    DataLegendSeriesContextDescriptionMetadata.c = function (a) {
        a.item("SeriesGroup", "ExportedType:string:DataLegendSeriesGroup");
        a.item("SeriesGroup@names", "Category;Range;Financial;Indicator;Polar;Radial;Scatter;Stacked;Shape;Geographic");
    };
    DataLegendSeriesContextDescriptionMetadata.d = function (a) {
        DataLegendSeriesContextDescriptionMetadata.b(a);
        a.u("DataLegendSeriesContext", function () { return new DataLegendSeriesContextDescription(); });
        a.t("DataLegendSeriesContext", DataLegendSeriesContextDescriptionMetadata.a);
    };
    DataLegendSeriesContextDescriptionMetadata.$t = markType(DataLegendSeriesContextDescriptionMetadata, 'DataLegendSeriesContextDescriptionMetadata');
    DataLegendSeriesContextDescriptionMetadata.a = null;
    return DataLegendSeriesContextDescriptionMetadata;
}(Base));
export { DataLegendSeriesContextDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/DataLegendSeriesContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataLegendSeriesContextDescription } from "./DataLegendSeriesContextDescription";
/**
 * @hidden
 */
var DataLegendSeriesContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(DataLegendSeriesContextDescriptionMetadata, _super);
    function DataLegendSeriesContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataLegendSeriesContextDescriptionMetadata.b = function (a) {
        if (DataLegendSeriesContextDescriptionMetadata.a == null) {
            DataLegendSeriesContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataLegendSeriesContextDescriptionMetadata.c(DataLegendSeriesContextDescriptionMetadata.a);
        }
        if (a.j(DataLegendSeriesContextDescriptionMetadata.a)) {
            return;
        }
        a.y(DataLegendSeriesContextDescriptionMetadata.a);
    };
    DataLegendSeriesContextDescriptionMetadata.c = function (a) {
        a.item("SeriesGroup", "ExportedType:string:DataLegendSeriesGroup");
        a.item("SeriesGroup@names", "Category;Range;Financial;Indicator;Polar;Radial;Scatter;Stacked;Shape;Geographic");
    };
    DataLegendSeriesContextDescriptionMetadata.d = function (a) {
        DataLegendSeriesContextDescriptionMetadata.b(a);
        a.aa("DataLegendSeriesContext", function () { return new DataLegendSeriesContextDescription(); });
        a.z("DataLegendSeriesContext", DataLegendSeriesContextDescriptionMetadata.a);
    };
    DataLegendSeriesContextDescriptionMetadata.$t = markType(DataLegendSeriesContextDescriptionMetadata, 'DataLegendSeriesContextDescriptionMetadata');
    DataLegendSeriesContextDescriptionMetadata.a = null;
    return DataLegendSeriesContextDescriptionMetadata;
}(Base));
export { DataLegendSeriesContextDescriptionMetadata };
